import setuptools 


setuptools.setup(
    name='SmjaAi',
    version='0.8',
    author='Ali-Mahmoud-Fadhil',
    description='By This Lib You Can Talk With ChatGPT And You can benefit from many tools in this library, so what are you waiting for? Go explore the library, bro  ,',
    packages=setuptools.find_packages(),
    
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License"
    ],
    install_requires=['requests']
)